#ModProcesso

modProcesso is a library for modularisation of automata generated by process mining.

#License

modProcesso is available by MIT License.

#Requirements:

You must install:

    teocomp
    pm4py
    ipywidgets
    automaton2bpmn

#Install


To install modProcesso from PyPi repository, run the following command:

pip install modProcesso